/*--------------------------------------------------------------------
 * $Id: make_slitfunction.c,v 1.2 2001/06/20 14:30:58 pa2h Exp $
 * 
 * This file is part of libRadtran.
 * Copyright (c) 1997-2001 by Arve Kylling and Bernhard Mayer.
 * 
 * ######### Contact info: http://www.libradtran.org #########
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License   
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.        
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of  
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the   
 * GNU General Public License for more details.                    
 * 
 * You should have received a copy of the GNU General Public License          
 * along with this program; if not, write to the Free Software                
 * Foundation, Inc., 59 Temple Place - Suite 330, 
 * Boston, MA 02111-1307, USA.
 *--------------------------------------------------------------------*/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "../src_c/getopt.h"

static void usage();

int main(int argc, char **argv) 
{

  int c=0;
  double resolution=0.0, fwhm=0.0;

  double lambda, lambda_range, func, func_step;
  int i, n_points=0, type=1;

  while ((c=getopt (argc, argv, "hr:f:t:")) != EOF)  {
    switch(c)  {
    case 'r': 
      resolution = atof(optarg);
      break;
    case 't': 
      type = atoi(optarg);
      break;
    case 'f': 
      fwhm = atof(optarg);
      break;
    case 'h':  /* Guess what */
      usage();
      return (-1);
      break;
    default:
      usage();
      return (-1);
    }
  }
   
  lambda_range = 2*fwhm;
  n_points     = (int) (lambda_range/resolution) + 1;
  func_step    = 1./(n_points/2);
  switch (type) {
  case 1: 
    for (i=0;i<n_points/2;i++) {
      lambda = -lambda_range/2. + i*resolution;
      func   = (double) i * func_step;
      printf("%8.3f %10.6f\n", lambda, func);
    }
    for (i=0;i<=n_points/2;i++) {
      lambda = i*resolution;
      func   = (double) (n_points/2 - i) * func_step;
      printf("%8.3f %10.6f\n", lambda, func);
    }
    break;
  case 2: 
    for (i=0;i<n_points/2;i++) {
      lambda = -lambda_range/2. + i*resolution;
      func   = (double) 1.;
      printf("%8.3f %10.6f\n", lambda, func);
    }
    for (i=0;i<=n_points/2;i++) {
      lambda = i*resolution;
      func   = (double) 1.;
      printf("%8.3f %10.6f\n", lambda, func);
    }
    break;
  }
  return 0;   /* if o.k. */
}

/*************************************************************/
/* print usage information                                   */
/*************************************************************/

static void usage()
{
  fprintf (stderr, "\nOutputs to stdout the wavelength and \n");
  fprintf (stderr, "corresponding value for a triangular slit function.\n");
  fprintf (stderr, "All options must be set.\n\n");
  fprintf (stderr, "No error checking yet, so be careful.\n\n");

  fprintf (stderr, "Usage: make_slitfunction [-hrft]\n");
  fprintf (stderr, " -t type of slitfunction\n");
  fprintf (stderr, "    1: triangular (default)\n");
  fprintf (stderr, "    2: rectangular\n");
  fprintf (stderr, " -f full width at half maximum, in nm\n");
  fprintf (stderr, " -r resolution, in nm\n");
  fprintf (stderr, " -h    Print this message.\n");  
}
